/*
 * $Id: shell.h 400 2007-01-29 18:52:56Z hubert@u.washington.edu $
 *
 * ========================================================================
 * Copyright 2006 University of Washington
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * ========================================================================
 */


#ifndef PICO_OSDEP_SHELL_INCLUDED
#define PICO_OSDEP_SHELL_INCLUDED


/* exported prototypes */
#if defined(SIGTSTP) || defined(_WINDOWS)
int	bktoshell(void);
#endif


#endif /* PICO_OSDEP_SHELL_INCLUDED */
